@@ -259,10 +259,9 @@ sub handle_command {
     my $self    = shift;
     my $content = shift;
 
-    my $output = $content;
-    $output =~ s/[\r\n]+$//;
+    $content =~ s/[\r\n]+$//;
     $self->log( 4,
-        "C(@{[$self]},@{[$self->auth ? $self->auth->user : '???']},@{[$self->is_selected ? $self->selected->full_path : 'unselected']}): $output"
+        "C(@{[$self]},@{[$self->auth ? $self->auth->user : '???']},@{[$self->is_selected ? $self->selected->full_path : 'unselected']}): $content"
     );
 
     if ( $self->pending ) {
@@ -361,7 +360,6 @@ undef if parsing fails for some reason.
 sub parse_command {
     my $self = shift;
     my $line = shift;
-    $line =~ s/[\r\n]+$//;
     my $TAG = qr/([^\(\)\{ \*\%"\\\+}]+)/;
     unless ( $line =~ /^$TAG\s+(\w+)(?:\s+(.+?))?$/ ) {
         if ( $line !~ /^$TAG\s+/ ) {
